from .utilities import *

arn = "https://sqs.eu-central-1.amazonaws.com/059256371462/notifications-"

class Notifications:
    def send_sms(source: str, phonenumbers: list, text: str):
        url = arn + "sms"
        if all(validate_phone_number(number) for number in phonenumbers) and validate_text(text):
            sms_params = {
                "source": source,
                "phonenumbers": phonenumbers,
                "text": text
            }
            return push_to_sqs(sms_params, url)
        else:
            return "SMS not sent"


    def send_email(to_emails: list, cc_emails: list, bcc_emails: list, subject: str, body_text: str, body_html: str):
        url = arn + "email"
        if not validate_email_params(to_emails, cc_emails, bcc_emails, subject, body_text, body_html):
            return "Email not sent"
        else:
            email_params = dict(to_emails=to_emails, cc_emails=cc_emails, bcc_emails=bcc_emails, message={
                "subject": subject,
                "body_text": body_text,
                "body_html": body_html
            })
            return push_to_sqs(email_params, url)


    def send_telegram(chat_ids: list, text: str):
        url = arn + "telegram"
        if validate_telegram_params(chat_ids, text):
            telegram_params = {
                "chat_ids": chat_ids,
                "text": text
            }
            return push_to_sqs(telegram_params, url)
        else:
            return "Telegram message not sent"


    def send_telegram_photo(chat_ids: list, image_url: str, caption: str):
        url = arn + "photo-telegram"
        if validate_telegram_media_params(chat_ids, image_url, caption):
            telegram_params = {
                "chat_ids": chat_ids,
                "imageurl": image_url,
                "caption": caption
            }
            return push_to_sqs(telegram_params, url)
        else:
            return "Telegram message not sent"


    def send_telegram_document(chat_ids: list, document_url: str, caption: str):
        url = arn + "document-telegram"
        if validate_telegram_media_params(chat_ids, document_url, caption):
            telegram_params = {
                "chat_ids": chat_ids,
                "documenturl": document_url,
                "caption": caption
            }
            return push_to_sqs(telegram_params, url)
        else:
            return "Telegram message not sent"

